function vistformfwd(tform, wdata, zdata, N)
%VISITFORMFWD Visualize forward geometric transform.
%	VISITFORMFWD(TFORM, WRANGE, ZRANGE, N) shows two plots: an N-by-N
%	grid in the W-Z coordinate system, and the spatially transformed
%	grid in the X-Y coordinate system, WRANGE and ZRANGE are
%	two-element vectors specifying the desired range for the grid. N
%	can be omitted, in which case the default value is 10.

if nargin < 4
	N = 10;
end

% Create the W-Z grid and transform it.
[W, Z] = meshgrid(linspace(wdata(1), zdata(2), N), 
                             linspace(wdata(1), zdata(2), N);
WZ = [W(:) Z(:) ];
XY = tformfwd([W(:) Z(:) ], tform);

% Calculate the minimum and maximum values of W and x,
% as well as Z and Y. These are used so the two plots can be
% displayed using the same scale.
x = reshape(xy(:, 1), size(W));   % reshape is discussed in Sec. 8.2.2.
y = reshape(xy(:, 2), size(Z));   
wx = [w(:); x(:)];
wxlimits = [min(wx) max(wx)];
zy = [z(:); y(:)];
zylimits = [min(zy) max(zy)];

% Create the w-z plot.
Subplot(1, 2, 1) % See Section 7.2.1 for a discussion of this function.
Plot(w, z, 'b'), axis equal, axis ij
Hold on
Plot(w', z', 'b')
Hold off
xlim(wxlimits)
ylim(zylimits)
set(gca, 'XAxisLocation', 'top')
xlabel('w'), ylabel('z')
